@@ -155,6 +155,9 @@ from botoolkit.core.commands import (
 from botoolkit.core.consts import (
     ALLOWED_ALL_EMPTY_CONFIG_PARAMETERS,
 )
+from botoolkit.core.helpers import (
+    parse_iterable_multiple_elements,
+)
 from botoolkit.core.loggers import (
     logger,
 )
@@ -261,9 +264,7 @@ class GenerateBaseDBImageSchemaCommand(
             action='store',
             default=False,
             type=lambda x: bool(strtobool(x)),
-            help=(
-                'Need generate test databases schemas'
-            ),
+            help='Нужно генерировать схему для базовых образов для тестов. По умолчанию, False.',
         )
 
         parser.add_argument(
@@ -272,7 +273,19 @@ class GenerateBaseDBImageSchemaCommand(
             action='store',
             default=None,
             type=lambda x: tuple(map(lambda project: ProjectEnum(project), x.split(','))),
-            help='Excluded projects',
+            help='Исключаемые проекты, перечисляются через запятую. Например, web_bb_vehicle,web_bb_food.',
+        )
+
+        parser.add_argument(
+            '--excluded_projects_combinations',
+            dest='excluded_projects_combinations',
+            action='store',
+            default=None,
+            type=lambda x: [tuple(ProjectEnum(p) for p in projects) for projects in parse_iterable_multiple_elements(x)],
+            help=(
+                'Исключаемые комбинации проектов. Пары перечисляются через запятую. Проекты в парах разделены |. '
+                'Например, web_bb_salary|web_bb_vehicle.'
+            ),
         )
 
         parser.add_argument(
@@ -281,7 +294,7 @@ class GenerateBaseDBImageSchemaCommand(
             action='store',
             default=(),
             type=lambda x: tuple(map(lambda branch: BranchEnum(branch), x.split(','))),
-            help='Excluded branches'
+            help='Исключаемые ветки, перечисляемые через зяпятую. Например, default.'
         )
 
         parser.add_argument(
@@ -290,7 +303,7 @@ class GenerateBaseDBImageSchemaCommand(
             action='store',
             default=BranchEnum.DEFAULT,
             type=lambda x: BranchEnum(x),
-            help='Branch using in generating base db images',
+            help='Ветка, считающаяся базовой для базовых образов БД. По умолчанию, default.',
         )
 
         return parser
