@@ -19,6 +19,9 @@ from typing import (
     Tuple,
 )
 
+from botoolkit.bo_web_bb.helpers import (
+    exclude_projects_combinations,
+)
 from botoolkit.core.helpers import (
     topological_sort,
 )
@@ -76,10 +79,10 @@ class ProjectEnum(Enum):
         )
 
     @classmethod
-    @lru_cache()
     def get_projects_combinations(
         cls,
         projects: Tuple['ProjectEnum'] = None,
+        excluded_projects_combinations: Optional[List[Tuple['ProjectEnum', ...]]] = None,
     ) -> List[Tuple['ProjectEnum']]:
         """
         Возвращает допустимые комбинации проектов
@@ -115,6 +118,12 @@ class ProjectEnum(Enum):
             if not is_dirty:
                 filtered_combinations.append(dirty_combination)
 
+        if excluded_projects_combinations:
+            filtered_combinations = exclude_projects_combinations(
+                projects_combinations=filtered_combinations,
+                excluded_projects_combinations=excluded_projects_combinations,
+            )
+
         return filtered_combinations
 
     @classmethod
@@ -1206,6 +1215,7 @@ class ProjectPluginEnum(Enum):
         cls,
         plugins: Tuple['ProjectPluginEnum'],
         exclude_projects: Optional[Tuple[ProjectEnum]] = None,
+        excluded_projects_combinations: Optional[List[Tuple[ProjectEnum, ...]]] = None,
     ) -> List[Tuple['ProjectEnum']]:
         """
         Получение допустимых комбинаций проектов для переданного списка плагинов
@@ -1221,6 +1231,12 @@ class ProjectPluginEnum(Enum):
             projects=tuple(projects),
         )
 
+        if excluded_projects_combinations:
+            projects_combinations = exclude_projects_combinations(
+                projects_combinations=projects_combinations,
+                excluded_projects_combinations=excluded_projects_combinations,
+            )
+
         return projects_combinations
 
     @classmethod
